@@ -1,9 +1,10 @@
 {-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE TypeApplications #-}
 import Network.Socks5
-import Network.Socket hiding (recv, sClose)
+import Network.Socket hiding (recv, close)
 import Network.Socket.ByteString
+import Network.Socket (close)
 import Network.BSD
-import Network
 import Data.ByteString.Char8 ()
 import qualified Data.ByteString.Char8 as BC
 
@@ -24,32 +25,22 @@ main = do
     example1 socksServerAddr destinationName
     example2 socksServerAddr destinationName
 
-    example3 serverName serverPort destinationName 80
-
   where
         -- connect to @destName on port 80 through the socks server
         -- www.google.com get resolve on the client here and then the sockaddr is
         -- passed to socksConnectAddr
         example1 socksServerAddr destName = do
-            socket <- socket AF_INET Stream defaultProtocol
-            socksConnectWithSocket socket (defaultSocksConfFromSockAddr socksServerAddr)
+            (socket, _) <- socksConnect (defaultSocksConf socksServerAddr)
                         (SocksAddress (SocksAddrDomainName $ BC.pack destName) 80)
 
             sendAll socket "GET / HTTP/1.0\r\n\r\n"
             recv socket 4096 >>= putStrLn . show
-            sClose socket
+            close socket
         -- connect to @destName on port 80 through the socks server
         -- the server is doing the resolution itself
         example2 socksServerAddr destName = do
             socket <- socket AF_INET Stream defaultProtocol
-            socksConnectName socket socksServerAddr destName 80
+            socksConnectName socket (defaultSocksConf socksServerAddr) destName 80
             sendAll socket "GET / HTTP/1.0\r\n\r\n"
             recv socket 4096 >>= putStrLn . show
-            sClose socket
-
-        example3 sname sport dname dport = do    
-            handle <- socksConnectTo sname (PortNumber sport) dname (PortNumber dport)
-            BC.hPut handle "GET / HTTP/1.0\r\n\r\n"
-            hFlush handle
-            BC.hGet handle 1024 >>= putStrLn . show
-            hClose handle
+            close socket
